<?php

/**
 * GepTextosoliLogic.
 *
 * @package Logic
 * @author  erikasouza
 *
 */
class GepTextosoliLogic{


    private $_GepTextosoliEntity;


    /**
     * Construtor da Classe.
     */
    public function __construct(){
        $this->_GepTextosoliEntity = new GepTextosoliEntity();
    }


    /**     ok
     * Gera novo codigo do texto a ser inserido para a solicitacao.
     *
     * @param integer $nrorg Numero da Organizacao.
     *
     * @return Ambigous <number, number>
     */
    public static function novoCodigoGepTextosoliLogic($nrorg){
        $codigo = GepTextosoliEntity::novoCodigoGepTextosoliLogic($nrorg);
        return $codigo;
    }


    /**      ok
     * Retorna lista com os textos para uma determinada solicitacao.
     *
     * @param integer $nrorg Numero da Organizacao.
     * @param integer $soli  Codigo da solicitacao.
     *
     * @return Ambigous <boolean, NULL, TkModelEntity>|boolean
     */
    public function retornaDadosTextoSoli($nrorg, $soli){
        try {
            $dados = $this->_GepTextosoliEntity->retornaDadosTextoSoli($nrorg, $soli);
            return $dados;
        } catch (Exception $e) {
            switch ($e->getCode()){
            case GepTextosoliEntity::SEM_REGISTRO:
                return GepTextosoliEntity::SEM_REGISTRO;
            default:
                tk_warning('Erro desconhecido: '.$e->getMessage());
                return false;
            }
        }
    }


    /**      ok
     * Insere um texto de uma determinada solicitacao.
     *
     * @param integer $soli          Numero da Solicitacao.
     * @param integer $ordem         Ordem de exibicao (opcional).
     * @param string  $grupo         Grupo a qual texto pertence (opcional).
     * @param string  $titulo        Titulo.
     * @param string  $texto         Texto.
     * @param string  $observ        Texto de Observacao do texto.
     * @param integer $nrorg         Numero da Organizacao.
     * @param date    $data          Data de insercao.
     * @param integer $operador      Operador de insercao.
     * @param string  $exclui_texto  Id para excluir o texto.
     * @param string  $alt_ordenacao Id para alterar ordenacao.
     * @param string  $alt_grupo     Id para alterar grupo.
     * @param string  $alt_titulo    Id para alterar titulo.
     *
     * @return boolean
     */
    public function insereTextosSoli(
        $soli, $ordem, $grupo, $titulo, $texto, $observ, $nrorg, $data,
        $operador, $exclui_texto, $alt_ordenacao, $alt_grupo, $alt_titulo
    ){
        $codigo = $this->_GepTextosoliEntity->novoCodigoGepTextosoliLogic($nrorg);
        if (empty($codigo) === true) {
            tk_warning('Erro ao inserir texto parametrizado!');
            return false;
        }

        $insere = $this->_GepTextosoliEntity->insereTextosSoli(
            $codigo, $soli, $ordem, $grupo, $titulo, $texto, $observ, $nrorg, $data,
            $operador, $exclui_texto, $alt_ordenacao, $alt_grupo, $alt_titulo
        );

        return $insere;
    }


    /**
     * Retorna os c?digos dos textos parametrizados na GEP_TEXTOSOLIFLUXO que faltam na solicita??o.
     *
     * @param integer $nrorg    N?mero da Organiza??o.
     * @param integer $tp_fluxo Tipo de fluxo.
     * @param integer $soli     N?mero da Solicita??o.
     *
     * @return Ambigous <boolean, multitype:>
     */
    public function retornaTextosFaltantesSoli($nrorg, $tp_fluxo, $soli){
        $id_textos = $this->_GepTextosoliEntity->retornaTextosFaltantesSoli($nrorg, $tp_fluxo, $soli);
        return $id_textos;
    }


    /**            ok
     * Retorna o maior valor de ordenacao entre os textos da solicitacao.
     *
     * @param integer $nrorg Numero da Organizacao.
     * @param integer $soli  Numero da solicitacao.
     *
     * @return Ambigous <boolean, multitype:>
     */
    public static function proximoValorOrdenacaoSoli($nrorg, $soli){
        $maior = GepTextosoliEntity::retornaMaiorValorOrdenacaoSoli($nrorg, $soli);

        if ($maior === null) {
            return $maior;
        } else {
            return ++$maior;
        }
    }


    /**      ok
     * Retorna o texto padrao do tipo de fluxo formatado.
     *
     * @param integer $nrorg    Numero da Organizacao.
     * @param integer $tp_fluxo Numero do tipo de fluxo.
     *
     * @return Ambigous <boolean, multitype:>
     */
    static function retornaTextoPadraoFluxo($nrorg, $tp_fluxo){
        $txt_format = GepTipofluxoLogic::retornaTextoFormat($nrorg, $tp_fluxo);
        return $txt_format;
    }


    public function retornaDadosTexto($nrorg, $texto){
        $dados = $this->_GepTextosoliEntity->retornaDadosTexto($nrorg, $texto);
        return $dados;
    }
}