/******************************************************************************/
/* Sistemas Integrados TECNISA                                                */
/*                                                                            */
/* Compras e Suprimentos                                                      */
/*                                                                            */
/******************************************************************************/
/*                                                                            */
/* Nome: 8480_SUPSTP_LOAD_ULTCOTFORN                                          */
/*                                                                            */
/* Descrio:                                                                 */
/*    Carrega a ltima cotao para do fornecedor                             */
/*                                                                            */
/* Criao:                                                                   */
/*    03/07/2000 - Adriano de Araujo                                          */
/*                                                                            */
/* Manutenes:                                                               */
/*   /  /   -                                                                 */
/*                                                                            */
/******************************************************************************/

/******************************************************************************/
/* @C:\SISTEMAS\DBA\SQL\ORACLE\8480_SUPSTP_LOAD_ULTCOTFORN.SQL               */
/* @H:\SISTEMAS\DBA\SQL\ORACLE\8480_SUPSTP_LOAD_ULTCOTFORN.SQL               */
/******************************************************************************/

CREATE OR REPLACE PROCEDURE LOAD_ULTCOTFORN
                     (P_CDFILIAL     IN COLETAPR.CDFILIAL%TYPE,
                      P_NRCOLEPRECO  IN COLETAPR.NRCOLEPRECO%TYPE,
                      P_CDFORNECED   IN VARCHAR2)
IS
 V_ULTCOT ITEMCOLE.NRCOLEPRECO%TYPE;
 V_DTCOL  COLETAPR.DTCOLEPREC%TYPE;

 V_ROWCOUNT INT;
 
BEGIN
  SELECT
    DTCOLEPREC INTO V_DTCOL
  FROM
   COLETAPR
  WHERE
   CDFILIAL    = P_CDFILIAL AND
   NRCOLEPRECO = P_NRCOLEPRECO;

  SELECT
    NVL(MAX(ITEMCOLE.NRCOLEPRECO),0) INTO V_ULTCOT
  FROM
    ITEMCOLE,
    FORNECEDOR
  WHERE
    ITEMCOLE.CDFILIAL     = P_CDFILIAL   AND
    ITEMCOLE.CDFORNECED   = P_CDFORNECED AND
    ITEMCOLE.NRCOLEPRECO  <> P_NRCOLEPRECO AND
    ITEMCOLE.CDFORNECED   = FORNECEDOR.CDFORNECED AND
    FORNECEDOR.IDSITUCADA = 'A' AND
    NOT EXISTS
     (SELECT
        FORNECEDOR.CDFORNECED
      FROM
        QUALIFICACAO,
        PARASUPRI
      WHERE
        FORNECEDOR.CDQUALIF = QUALIFICACAO.CDQUALIF AND
        (PARASUPRI.CDFILIAL = P_CDFILIAL) AND
        (FORNECEDOR.IDFORNAUTO = 'N') AND
        ((QUALIFICACAO.IDPERCOTCMP = '2') OR
        ( (PARASUPRI.IDULTIDTVALQ = 'D' AND
         V_DTCOL > FORNECEDOR.DTVALQUALIF) OR
        (PARASUPRI.IDULTIDTVALQ = 'M' AND
         V_DTCOL > LAST_DAY(FORNECEDOR.DTVALQUALIF)) )) );

  V_ULTCOT := LPAD(V_ULTCOT, 10, '0');

  FOR C_ULTCOT IN (SELECT
                     ITEMCOLE.CDPRODUTO,
                     ITEMCOLE.CDMARCA,
                     ITEMCOLE.CDREGIAO,
                     ITEMCOLE.VRPRECUNIITM, ITEMCOLE.CDTIPCOB,
                     ITEMCOLE.CDSEGMARCCOL, ITEMCOLE.VRPERDESITM,
                     ITEMCOLE.IDTIPFREITM,  ITEMCOLE.NRPZOENTCOL,
                     ITEMCOLE.CDFORMPGTO,   ITEMCOLE.IDTPFOPGTCOL,
                     ITEMCOLE.NRPARCPGTCOL, ITEMCOLE.NRDIAPGFXCOL,
                     ITEMCOLE.IDUTDIAPGCOL,
                     ITEMCOLE.DSPZOPGTCONC
                   FROM
                     ITEMCOLE
                  WHERE
                     ITEMCOLE.CDFILIAL     = P_CDFILIAL   AND
                     ITEMCOLE.NRCOLEPRECO  = V_ULTCOT     AND
                     ITEMCOLE.CDFORNECED   = P_CDFORNECED)LOOP
    UPDATE ITEMCOLE
    SET
       ITEMCOLE.VRPRECUNIITM  = C_ULTCOT.VRPRECUNIITM,
       ITEMCOLE.CDTIPCOB      = C_ULTCOT.CDTIPCOB,
       ITEMCOLE.CDSEGMARCCOL  = C_ULTCOT.CDSEGMARCCOL,
       ITEMCOLE.VRPERDESITM   = C_ULTCOT.VRPERDESITM,
       ITEMCOLE.IDTIPFREITM   = C_ULTCOT.IDTIPFREITM,
       ITEMCOLE.NRPZOENTCOL   = C_ULTCOT.NRPZOENTCOL,
       ITEMCOLE.CDFORMPGTO    = C_ULTCOT.CDFORMPGTO ,
       ITEMCOLE.IDTPFOPGTCOL  = C_ULTCOT.IDTPFOPGTCOL,
       ITEMCOLE.NRPARCPGTCOL  = C_ULTCOT.NRPARCPGTCOL,
       ITEMCOLE.NRDIAPGFXCOL  = C_ULTCOT.NRDIAPGFXCOL,
       ITEMCOLE.IDUTDIAPGCOL  = C_ULTCOT.IDUTDIAPGCOL,
       ITEMCOLE.DSPZOPGTCONC  = C_ULTCOT.DSPZOPGTCONC
    WHERE
      ITEMCOLE.CDFILIAL     = P_CDFILIAL    AND
      ITEMCOLE.NRCOLEPRECO  = P_NRCOLEPRECO AND
      ITEMCOLE.CDFORNECED   = P_CDFORNECED  AND
      ITEMCOLE.CDPRODUTO    = C_ULTCOT.CDPRODUTO AND
      ITEMCOLE.CDMARCA      = C_ULTCOT.CDMARCA   AND
      ITEMCOLE.CDREGIAO     = C_ULTCOT.CDREGIAO;

      V_ROWCOUNT := V_ROWCOUNT + SQL%ROWCOUNT;
  END LOOP;
  IF V_ROWCOUNT > 0 THEN
    INSERT INTO PZOPGTITMCOL
      (CDFILIAL, NRCOLEPRECO, CDFORNECED, CDPRODUTO,
      CDMARCA, CDREGIAO, NRDIASPGTCOL, VRPERCPGTCOL)
    SELECT
       PZOPGTITMCOL.CDFILIAL,
       P_NRCOLEPRECO,
       PZOPGTITMCOL.CDFORNECED,
       PZOPGTITMCOL.CDPRODUTO,
       PZOPGTITMCOL.CDMARCA,
       PZOPGTITMCOL.CDREGIAO,
       PZOPGTITMCOL.NRDIASPGTCOL,
       PZOPGTITMCOL.VRPERCPGTCOL
    FROM
       PZOPGTITMCOL,
       ITEMCOLE
    WHERE
       PZOPGTITMCOL.CDFILIAL    = P_CDFILIAL   AND
       PZOPGTITMCOL.NRCOLEPRECO = V_ULTCOT     AND
       PZOPGTITMCOL.CDFORNECED  = P_CDFORNECED AND
       ITEMCOLE.NRCOLEPRECO = P_NRCOLEPRECO           AND
       ITEMCOLE.CDFILIAL    = PZOPGTITMCOL.CDFILIAL   AND
       ITEMCOLE.CDFORNECED  = PZOPGTITMCOL.CDFORNECED AND
       ITEMCOLE.CDPRODUTO   = PZOPGTITMCOL.CDPRODUTO  AND
       ITEMCOLE.CDMARCA     = PZOPGTITMCOL.CDMARCA    AND
       ITEMCOLE.CDREGIAO    = PZOPGTITMCOL.CDREGIAO;

    INSERT INTO IMPCOLET
      (CDFILIAL, NRCOLEPRECO, CDFORNECED, CDPRODUTO,
       CDMARCA, CDREGIAO, CDIMPOSTO, VRALIQIMPCOL,
       VRPERRBCALCO, VRIMPCOLETA, VRBASECALCOL,
       VRPARCDEDCOL, CDFISCITMCOL, VRADIMPCOL)
    SELECT
      IMPCOLET.CDFILIAL,
      P_NRCOLEPRECO,
      IMPCOLET.CDFORNECED,
      IMPCOLET.CDPRODUTO,
      IMPCOLET.CDMARCA,
      IMPCOLET.CDREGIAO,
      IMPCOLET.CDIMPOSTO,
      IMPCOLET.VRALIQIMPCOL,
      IMPCOLET.VRPERRBCALCO,
      IMPCOLET.VRIMPCOLETA,
      IMPCOLET.VRBASECALCOL,
      IMPCOLET.VRPARCDEDCOL,
      IMPCOLET.CDFISCITMCOL,
      IMPCOLET.VRADIMPCOL
    FROM
      IMPCOLET,
      ITEMCOLE
    WHERE
      IMPCOLET.CDFILIAL    = P_CDFILIAL   AND
      IMPCOLET.NRCOLEPRECO = V_ULTCOT     AND
      IMPCOLET.CDFORNECED  = P_CDFORNECED AND
      ITEMCOLE.NRCOLEPRECO = P_NRCOLEPRECO       AND
      ITEMCOLE.CDFILIAL    = IMPCOLET.CDFILIAL   AND
      ITEMCOLE.CDFORNECED  = IMPCOLET.CDFORNECED AND
      ITEMCOLE.CDPRODUTO   = IMPCOLET.CDPRODUTO  AND
      ITEMCOLE.CDMARCA     = IMPCOLET.CDMARCA    AND
      ITEMCOLE.CDREGIAO    = IMPCOLET.CDREGIAO;

    /* Forando execuo da trigger para clculo do preo econmico */
    UPDATE ITEMCOLE
    SET IDTPFOPGTCOL = IDTPFOPGTCOL
    WHERE
     CDFILIAL    = P_CDFILIAL  AND
     NRCOLEPRECO = P_NRCOLEPRECO;
  END IF;
END;
/
